@@ -1,21 +1,16 @@
-from __future__ import absolute_import, division, print_function, unicode_literals
-
-from builtins import bytes, str
-from future.utils import PY2
+from __future__ import generator_stop
 
 import os.path
-from os import remove
-from sys import getfilesystemencoding
+from os import fspath, remove, replace
 from tempfile import mkstemp
 from typing import TYPE_CHECKING
 
-from .compat.os import fspath, replace
 from .file import copen
 
 if TYPE_CHECKING:
+	from os import PathLike
 	from typing import IO, ContextManager, Optional, Union
 
-	from .compat.os import PathLike
 	PathType = Union[str, PathLike]
 
 # http://stupidpythonideas.blogspot.tw/2014/07/getting-atomic-writes-right.html
@@ -30,9 +25,6 @@ class TransactionalCreateFile(object):
 		suffix = os.path.splitext(self.path)[1].lower()
 		curdir = os.path.dirname(self.path)
 		fd, self.tmppath = mkstemp(suffix, prefix, curdir, is_text)
-		if PY2:
-			self.tmppath = self.tmppath.decode(getfilesystemencoding())
-
 		self.fp = copen(fd, mode, encoding=encoding, errors=errors, newline=newline, ext=suffix)
 
 	def commit(self):
