@@ -3,9 +3,33 @@ from __future__ import generator_stop
 from logging import Formatter
 from typing import TYPE_CHECKING
 
+from .datetime import datetime_from_utc_timestamp
+
 if TYPE_CHECKING:
 	from logging import LogRecord
-	from typing import Any, Dict
+	from typing import Any, Dict, Optional
+
+class IsoDatetimeFormatter(Formatter):
+
+	""" Displays the time in ISO 8601 format.
+		Instead of passing a formatting string to `datefmt` in the initializer, `sep` and `timespec`
+		(see `datetime.datetime.isoformat`) as well as `aslocal` (see genutility.datetime.datetime_from_utc_timestamp`)
+		can be passed.
+	"""
+
+	def __init__(self, fmt=None, datefmt=None, style='%', validate=True, sep='T', timespec='auto', aslocal=False):
+		# type: (Optional[str], None, str, bool, str, str, bool) -> None
+
+		Formatter.__init__(self, fmt, datefmt, style, validate)
+		assert datefmt is None
+		self.sep = sep
+		self.timespec = timespec
+		self.aslocal = aslocal
+
+	def formatTime(self, record, datefmt):
+		# type: (LogRecord, None) -> str
+
+		return datetime_from_utc_timestamp(record.created, aslocal=self.aslocal).isoformat(self.sep, self.timespec)
 
 class OverwriteFormatter(Formatter):
 
