@@ -1,4 +1,4 @@
-from __future__ import absolute_import, division, print_function, unicode_literals
+from __future__ import generator_stop
 
 from typing import TYPE_CHECKING
 
@@ -30,7 +30,7 @@ def multiline_textsize(text, ttf, spacing=4):
 def exifinfo(image):
 	# type: (Image, ) -> Dict[str, Any]
 
-	ret = dict()
+	ret = dict() # type: Dict[str, Any]
 
 	exifd = image._getexif()
 
