@@ -1,12 +1,10 @@
 from __future__ import generator_stop
 
 from collections.abc import Iterable, Sized
-from typing import TYPE_CHECKING
+from typing import TYPE_CHECKING, Any, Optional, Sequence, TypeVar, Union
 
 if TYPE_CHECKING:
 
-	from typing import Any, Optional, Sequence, TypeVar, Union
-
 	from typing_extensions import Protocol
 
 	Number = Union[int, float]
