@@ -1,8 +1,5 @@
-from __future__ import absolute_import, division, print_function, unicode_literals
+from __future__ import generator_stop
 
-from builtins import str
-
-from io import open
 from typing import TYPE_CHECKING
 
 from ruamel.yaml import YAML
